# eric7.EricWidgets.EricProxyStyle

Module implementing a proxy style to allow item selection by single/double click or platform default.

### Global Attributes

None

### Classes

EricProxyStyle | Class implementing a proxy style to allow item selection by single/double click or platform default.

### Functions

None

## EricProxyStyle

Class implementing a proxy style to allow item selection by single/double click or platform default.

### Derived from

QProxyStyle

### Class Attributes

None

### Class Methods

None

### Methods

EricProxyStyle | Constructor
styleHint | Public method returning a style hint for the given widget described by the provided style option.

### Static Methods

None

#### EricProxyStyle (Constructor)

EricProxyStyle(style=None, itemClickBehavior="default")

Constructor

style (QStyle, str or None (optional))
  style object or style name or None for the default native style (defaults to None)
itemClickBehavior (str (optional))
  string describing the item activation behavior (one of "default", "doubleclick" or "singleclick") (defaults to "default")

#### EricProxyStyle.styleHint

styleHint(hint, option=None, widget=None, returnData=None)

Public method returning a style hint for the given widget described by the provided style option.

hint (QStyle.StyleHint)
  style hint to be determined
option (QStyleOption (optional))
  style option (defaults to None)
widget (QWidget (optional))
  reference to the widget (defaults to None)
returnData (QStyleHintReturn (optional))
  data structure to return more data (defaults to None)

Return:
  integer representing the style hint

Return Type:
  int

Up